@@ -61,16 +61,16 @@ class API(object):
         asset_id = kwargs.get("asset_id", "Unknown") or "Unknown"
 
         if response.status_code == 401:
-            raise exceptions.APIError("Unable to reach Corva API: {}".format(response.content))
+            raise exceptions.APIError("Unable to reach Corva API")
 
         if response.status_code == 403:
             raise exceptions.Forbidden("No access to asset {0}".format(asset_id))
 
         if response.status_code == 404:
-            raise exceptions.AssetNotFound("Asset {0} Not Found".format(asset_id))
+            raise exceptions.NotFound("Not Found")
 
         if not response.ok:
-            raise exceptions.APIError("Unable to reach Corva API: {}".format(response.content))
+            raise exceptions.APIError("Unable to reach Corva API")
 
         result = Result(response, **kwargs)
         return result
