@@ -47,13 +47,13 @@ class RedisMixin(object):
 class LoggingMixin(object):
 
     LOGGING_LEVELS = [
-        "all",  # lowest level
+        "off",
+        "all",
         "debug",
         "info",
         "warn",
         "error",
-        "fatal",
-        "off"
+        "fatal"
     ]
 
     def __init__(self, *args, **kwargs):
@@ -90,7 +90,10 @@ class LoggingMixin(object):
         pass
 
     def call(self, method, asset_id, text):
-        method_check = str(method) in self.LOGGING_LEVELS[0:self.LOGGING_LEVELS.index(self.logging_level) + 1]
+        if method == 'off':
+            return
+
+        method_check = str(method) in self.LOGGING_LEVELS[1:self.LOGGING_LEVELS.index(self.logging_level) + 1]
         if not method_check:
             return
 
