@@ -28,7 +28,7 @@ from tqdm import tqdm
 from worker import constants
 from worker.data.operations import delete_collection_data_of_asset_id, get_one_wits_record
 from worker.framework.mixins import RedisMixin
-from worker.test import get_last_processed_timestamp, create_scheduler_events
+from worker.test.utils import get_last_processed_timestamp, create_scheduler_events
 
 
 def generate_parser():
@@ -46,18 +46,19 @@ def generate_parser():
 
 
 class AppTestRun:
-    def __init__(self, lambda_handler, collections):
+    def __init__(self, lambda_handler, collections, args=None):
         self.lambda_handler = lambda_handler
         self.collections = collections
 
         self.progress = None
 
-        self.initialize()
+        if args is None:
+            parser = generate_parser()
+            args = parser.parse_args()
 
-    def initialize(self):
-        parser = generate_parser()
-        args = parser.parse_args()
+        self.initialize(args)
 
+    def initialize(self, args):
         asset_id = args.asset_id
         start_timestamp = args.start_timestamp
         end_timestamp = args.end_timestamp
@@ -67,13 +68,13 @@ class AppTestRun:
         app_redis = "corva/{0}.{1}".format(asset_id, constants.get("global.app-key"))
 
         if not start_timestamp:
-            start_timestamp = get_one_wits_record(asset_id, timestamp_sort=+1)
+            start_timestamp = get_one_wits_record(asset_id, timestamp_sort=+1).get('timestamp')
         if not end_timestamp:
-            end_timestamp = get_one_wits_record(asset_id, timestamp_sort=-1)
+            end_timestamp = get_one_wits_record(asset_id, timestamp_sort=-1).get('timestamp')
         if to_delete:
             RedisMixin.delete_states(pattern=f"{app_redis}*")
-            for collection in self.collections:
-                delete_collection_data_of_asset_id(asset_id, collection)
+            delete_collection_data_of_asset_id(asset_id, self.collections)
+            print("Deleted relevant states and collections for this asset!")
 
         start_timestamp = get_last_processed_timestamp(app_redis) or start_timestamp
         print(f"asset_id: {asset_id}, timestamp interval: [{start_timestamp}, {end_timestamp}]")
